package net.jxta.impl.shell.bin.example5_1;

import java.io.ByteArrayInputStream;
import java.io.IOException;

import net.jxta.exception.NoResponseException;
import net.jxta.exception.DiscardQueryException;
import net.jxta.exception.ResendQueryException;

import net.jxta.impl.protocol.ResolverResponse;

import net.jxta.protocol.ResolverQueryMsg;
import net.jxta.protocol.ResolverResponseMsg;

import net.jxta.resolver.QueryHandler;


/**
 * A simple handler to process Resolver queries.
 */
class ExampleHandler implements QueryHandler
{
    /**
     * Processes the Resolver query message and returns a response. 
     *
     * @param       query the Resolver Query Message to be processed.
     * @return      a Resolver Response Message to send to the peer 
     *              responsible for sending the query.
     * @exception   IOException throw if the query string can't be parsed.
     */
    public ResolverResponseMsg processQuery(ResolverQueryMsg query) 
        throws IOException, NoResponseException, DiscardQueryException, 
            ResendQueryException
    {
        ResolverResponse response;
        ExampleQueryMsg eq;
        double answer = 0.0;
        
        System.out.println("Processing query...");

        // Parse the message from the query string.
        eq = new ExampleQueryMsg(
            new ByteArrayInputStream((query.getQuery()).getBytes()));

        // Perform the calculation.
        answer = Math.pow(eq.getBase(), eq.getPower());
        
        // Create the response message.
        ExampleResponseMsg er = new ExampleResponseMsg(eq.getBase(),
            eq.getPower(), answer);

        // Wrap the response message in a resolver response message.
        // The following is the old API way of creating a ResolverResponse,
        // eliminated in the new (build 65e) stable release.
        //response = new ResolverResponse("ExampleHandler",
        //    "JXTACRED", query.getQueryId(), er.toString());
        // Here is the new way:
        response = new ResolverResponse("ExampleHandler",
            null, query.getQueryId(), er.toString());

        return response;
    }

    /**
     * Process a Resolver response message.
     *
     * @param   response the Resolver Response Message to be processed.
     */
    public void processResponse(ResolverResponseMsg response)
    {
        ExampleResponseMsg er;
        
        System.out.println("Processing response...");

        try
        {
            // Extract the message from the Resolver response.
            er = new ExampleResponseMsg(
                new ByteArrayInputStream(
                    (response.getResponse()).getBytes()));
            
            // Print out the answer given in the response.
            System.out.println(
                "The value of " + er.getBase() + " raised to "
                    + er.getPower() + " is: " + er.getAnswer()); 
        }
        catch (IOException e)
        {
            // This is not the right type of response message, or
            // the message is improperly formed. Ignore the message,
            // do nothing.
        }
    }
}