package net.jxta.impl.shell.bin.example7_1;

import java.io.StringWriter;

import java.util.Enumeration;

import net.jxta.document.StructuredTextDocument;
import net.jxta.document.MimeMediaType;

import net.jxta.peer.PeerInfoEvent;
import net.jxta.peer.PeerInfoListener;

import net.jxta.protocol.PeerInfoResponseMessage;


/**
 * A simple implementation of PeerInfoListener to print out details on
 * the received Peer Info Response Messages.
 */
public class ExampleListener implements PeerInfoListener
{
    /**
     * A simple handler that prints out the details on the received
     * peer status information.
     *
     * @param   event the event detailing the received response.
     */
    public void peerInfoResponse(PeerInfoEvent event)
    {
        // Extract the peer info response from the event.
        // The following is the old API way of getting the response from
        // the event, now eliminated in the new (build 65e) stable release.
        //PeerInfoResponseMessage response = 
        //    event.getPPeerInfoResponseMessage();
        // Here is the new way (spelling corrected in new API):
        PeerInfoResponseMessage response = 
            event.getPeerInfoResponseMessage();

        // Print out the peer info.
        System.out.println("Uptime: " + response.getUptime());
        System.out.println("Timestamp: " + response.getTimestamp());
        System.out.println("Target: " + response.getTargetPid());
        System.out.println("Source: " + response.getSourcePid());
        System.out.println("Last Incoming Message: " 
            + response.getLastIncomingMessageTime());
        System.out.println("Last Outcoming Message: " 
            + response.getLastOutgoingMessageTime());

        // Print out the incoming channel statistics.
        Enumeration incoming = response.getIncomingTrafficChannels();
        if (incoming != null)
        {
            while (incoming.hasMoreElements())
            {
                String incomingchannel = (String) incoming.nextElement();
                long incomingbytes = 
                    response.getIncomingTrafficOnChannel(incomingchannel);

                System.out.println(
                    incomingbytes + " incoming bytes on channel " 
                        + incomingchannel);
            }
        }

        // Print out the outgoing channel statistics.
        Enumeration outgoing = response.getOutgoingTrafficChannels();
        if (outgoing != null)
        {
            while (outgoing.hasMoreElements())
            {
                String outgoingchannel = (String) outgoing.nextElement();
                long outgoingbytes =
                    response.getOutgoingTrafficOnChannel(outgoingchannel);

                System.out.println(
                    outgoingbytes + " incoming bytes on channel " 
                        + outgoingchannel);
            }
        }

        System.out.println("Done with status info...");
    }
}