package com.newriders.jxta.chapter10;

import net.jxta.service.Service;


/**
 * An interface for the ExampleService. This interface defines the 
 * operations that a developer can expect to use to manipulate the
 * ExampleService regardless of which underlying implementation of
 * the service is being used.
 */
public interface ExampleService extends Service
{
    /**
     * Add a listener object to the service. When new ExampleResponseMsg 
     * responses arrive, the service will notify each registered listener.
     *
     * @param   listener the listener object to register with the service.
     */
    public void addListener(ExampleServiceListener listener);

    /**
     * Send a query to the network to determine the value of the given 
     * base raised to the given power.
     *
     * @param   base the base for the exponentiation operation.
     * @param   power the exponent for the exponentiation operation.
     */
    public void findAnswer(double base, double power);

    /**
     * Remove a given listener object from the service. Once removed, 
     * a listener will no longer be notified when a new ExampleResponseMsg
     * response arrives.
     *
     * @param   listener the listener object to unregister.
     */
    public void removeListener(ExampleServiceListener listener);
}

