package net.jxta.impl.shell.bin.example4_2;

import net.jxta.discovery.DiscoveryService;
import net.jxta.discovery.DiscoveryListener;

import net.jxta.peergroup.PeerGroup;

import net.jxta.impl.shell.GetOpt;
import net.jxta.impl.shell.ShellApp;
import net.jxta.impl.shell.ShellEnv;
import net.jxta.impl.shell.ShellObject;


/**
 * A simple example shell application to register or unregister a
 * DiscoveryListener.
 */
public class example4_2 extends ShellApp
{
    /**
     * The shell environment holding the store of environment variables.
     */
    ShellEnv theEnvironment;

    /**
     * A flag indicating whether to add or remove the listener.
     */
    boolean addListener = true;

    /**
     * The name used to store the listener in the environment.
     */
    String name = "Default";


    /**
     * Manages adding or removing the listener.
     *
     * @param   discovery the Discovery service to use to manage 
     *          the listener.
     */
    private void manageListener(DiscoveryService discovery)
    {
        if (name != null)
        {
            // Check if a listener already exists.
            ShellObject theShellObject = theEnvironment.get(name);

            if (addListener)
            {
                if (theShellObject == null)
                {
                    // Create a new listener.
                    DiscoveryListener listener = new ExampleListener();

                    // Add the listener to the discovery service.
                    discovery.addDiscoveryListener(listener);

                    // Add the listener object to the environment.
                    theEnvironment.add(name, 
                        new ShellObject(name, listener));
                }
            }
            else
            {
                if (theShellObject != null)
                {
                    DiscoveryListener listener = 
                        (DiscoveryListener) theShellObject.getObject();

                    // Remove the listener from the discovery service.
                    discovery.removeDiscoveryListener(listener);

                    // Remove the listener object from the environment.
                    theEnvironment.remove(name);
                }
            }
        }
    }

    /**
     * Parses the command-line arguments and initializes the command
     *
     * @param       args the arguments to be parsed.
     * @exception   IllegalArgumentException if an invalid parameter 
     *              is passed.
     */
    private void parseArguments(String[] args) 
        throws IllegalArgumentException
    {
        int option;

        // Parse the arguments to the command.
        GetOpt parser = new GetOpt(args, "rn:");

        while ((option = parser.getNextOption()) != -1)
        {
            switch (option)
            {
                case 'r' :
                {
                    // Remove the listener.
                    addListener = false;
                    break;
                }

                case 'n' :
                {
                    // Get the name used to store the listener object.
                    String argument= null;

                    if ((argument = parser.getOptionArg()) != null)
                    {
                        name = argument;
                    }

                    break;
                }
            }
        }
    }

    /**
     * The implementation of the Shell command, invoked when the command 
     * is started by the user from the Shell.
     *
     * @param   args the command-line arguments passed to the command.
     * @return  a status code indicating the success or failure of 
     *          the command.
     */
    public int startApp(String[] args)
    {
        int result = appNoError;

        // Get the shell's environment.
        theEnvironment = getEnv();

        // Use the environment to obtain the current peer group.
        ShellObject theShellObject = theEnvironment.get("stdgroup");
        PeerGroup currentGroup = (PeerGroup) theShellObject.getObject();

        // Get the Discovery service for the current peer group.
        DiscoveryService discovery = currentGroup.getDiscoveryService();

        try
        {
            // Parse the command-line arguments.
            parseArguments(args);
        }
        catch (IllegalArgumentException e)
        {
            println("Incorrect parameters passed to the command.");
            result = ShellApp.appParamError;
        }

        // Manage the listener to the Discovery service. This
        // adds or removes the listener as specified by the
        // command-line parameters.
        manageListener(discovery);

        return result;
    }
}

