package net.jxta.impl.shell.bin.example4_4;

import java.io.IOException;

import java.util.Enumeration;

import net.jxta.discovery.DiscoveryService;

import net.jxta.document.Advertisement;

import net.jxta.peergroup.PeerGroup;

import net.jxta.impl.shell.GetOpt;
import net.jxta.impl.shell.ShellApp;
import net.jxta.impl.shell.ShellEnv;
import net.jxta.impl.shell.ShellObject;


/**
 * A simple example shell application to enable a user to send local
 * discovery queries using the current peer group's Discovery service.
 */
public class example4_4 extends ShellApp
{
    /**
     * The type of advertisement to discover. Defaults to 
     * peer advertisements.
     */
    private int type = DiscoveryService.PEER;

    /**
     * The Discovery service being used to discover advertisements.
     */
    private DiscoveryService discovery = null;

    /**
     * The name of the element to match.
     */
    private String attribute = null;

    /**
     * The value to match for the element specified by the attribute
     * variable.
     */
    private String value = null;
 
     
    /**
     * Parses the command-line arguments and initializes the command
     *
     * @param       args the arguments to be parsed.
     * @exception   IllegalArgumentException if an invalid parameter 
     *       is passed.
     */
    private void parseArguments(String[] args) 
        throws IllegalArgumentException
    {
        int option;

        // Parse the arguments to the command.
        GetOpt parser = new GetOpt(args, "a:k:v:");

        while ((option = parser.getNextOption()) != -1)
        {
            switch (option)
            {
                case 'a' :
                {
                    // Set the type of advertisement to discover.
                    type = Integer.parseInt(parser.getOptionArg());

                    // Validate the type.
                    if ((type < 0) || (type > 2))
                    {
                        // Default to the peer type.
                        type = DiscoveryService.PEER;
                    }

                    break;
                }

                case 'k' :
                {
                    // Set the attribute to match.
                    attribute = parser.getOptionArg();

                    break;
                }

                case 'v' :
                {
                    // Set the value for the attribute being matched.
                    value = parser.getOptionArg();

                    break;
                }
            }
        }

        // Both attribute and value must be specified.
        if (!((null != attribute) && (null != value)))
        {
            // Set both to null.
            attribute = null;
            value = null;
        }
    }

    /**
     * Sends a local discovery request using the Discovery service.
     */
    private void sendLocalDiscovery()
    {
        try
        {
            int count = 0;
            Enumeration enum = 
                discovery.getLocalAdvertisements(type, attribute, value);
            Advertisement advertisement;

            // Iterate through the response advertisements.
            while (enum.hasMoreElements())
            {
                // Get the next element from the enumeration.
                advertisement = (Advertisement) enum.nextElement();

                println("Found a matching advertisement!");

                // Increment the counter.
                count++;
            }

            println("Found " + count + " advertisements!");
        }
        catch (IOException e)
        {
            println("Error discovering local advertisements!" + e);
        }
    }

    /**
     * The implementation of the Shell command, invoked when the command 
     * is started by the user from the Shell.
     *
     * @param   args the command-line arguments passed to the command.
     * @return  a status code indicating the success or failure of 
     *          the command.
     */
    public int startApp(String[] args)
    {
        int result = appNoError;

        // Get the shell's environment.
        ShellEnv theEnvironment = getEnv();

        // Use the environment to obtain the current peer group.
        ShellObject theShellObject = theEnvironment.get("stdgroup");
        PeerGroup currentGroup = (PeerGroup) theShellObject.getObject();

        // Get the Discovery service for the current peer group.
        discovery = currentGroup.getDiscoveryService();

        try
        {
            // Parse the command-line arguments.
            parseArguments(args);
        }
        catch (IllegalArgumentException e)
        {
            println("Incorrect parameters passed to the command.");
            result = ShellApp.appParamError;
        }

        // Send a local discovery request.
        sendLocalDiscovery();

        return result;
    }
}