package net.jxta.impl.shell.bin.example4_5;

import java.io.IOException;

import net.jxta.discovery.DiscoveryService;

import net.jxta.peergroup.PeerGroup;

import net.jxta.impl.shell.GetOpt;

import net.jxta.impl.shell.ShellApp;
import net.jxta.impl.shell.ShellEnv;
import net.jxta.impl.shell.ShellObject;


/**
 * A simple example shell application to enable a user to flush 
 * discovered advertisements from the local cache using the current peer 
 * group's Discovery service.
 */
public class example4_5 extends ShellApp
{
    /**
     * The type of advertisement to flush. Defaults to peer advertisements.
     */
    private int type = DiscoveryService.PEER;

    /**
     * The ID of the advertisement to flush. Defaults to null.
     */
    private String id = null;

    
    /**
     * Parses the command-line arguments and initializes the command
     *
     * @param       args the arguments to be parsed.
     * @exception   IllegalArgumentException if an invalid parameter 
     *              is passed.
     */
    private void parseArguments(String[] args) 
        throws IllegalArgumentException
    {
        int option;

        // Parse the arguments to the command.
        GetOpt parser = new GetOpt(args, "a:i:");

        while ((option = parser.getNextOption()) != -1)
        {
            switch (option)
            {
                case 'a' :
                {
                    // Set the type of advertisement to flush.
                    type = Integer.parseInt(parser.getOptionArg());

                    // Validate the type.
                    if ((type < 0) || (type > 2))
                    {
                        // Default to the peer type.
                        type = DiscoveryService.PEER;
                    }

                    break;
                }
                
                case 'i' :
                {
                    // Set the ID string of the advertisement to flush.
                    id = parser.getOptionArg();

                    break;
                }
            }
        }
    }

    /**
     * The implementation of the Shell command, invoked when the command 
     * is started by the user from the Shell.
     *
     * @param   args the command-line arguments passed to the command.
     * @return  a status code indicating the success or failure of 
     *          the command.
     */
    public int startApp(String[] args)
    {
        int result = appNoError;

        // Get the shell's environment.
        ShellEnv theEnvironment = getEnv();

        // Use the environment to obtain the current peer group.
        ShellObject theShellObject = theEnvironment.get("stdgroup");
        PeerGroup currentGroup = (PeerGroup) theShellObject.getObject();

        // Get the DiscoveryService service for the current peer group.
        DiscoveryService discovery = currentGroup.getDiscoveryService();

        try
        {
            // Parse the command-line arguments.
            parseArguments(args);

            // Flush all of the advertisements of the given type and ID.
            discovery.flushAdvertisements(id, type);
        }
        catch (IllegalArgumentException e)
        {
            println("Incorrect parameters passed to the command.");
            result = ShellApp.appParamError;
        }
        catch (IOException e)
        {
            println("Error flushing advertisements: " + e);
            result = appMiscError;
        }

        return result;
    }
}