package net.jxta.impl.shell.bin.example4_6;

import java.io.IOException;

import net.jxta.discovery.DiscoveryService;

import net.jxta.document.AdvertisementFactory;

import net.jxta.id.IDFactory;

import net.jxta.peergroup.PeerGroup;

import net.jxta.protocol.PeerGroupAdvertisement;

import net.jxta.impl.shell.ShellApp;
import net.jxta.impl.shell.ShellEnv;
import net.jxta.impl.shell.ShellObject;


/**
 * A simple example shell application to publish a peer group
 * advertisement based on the Shell's current peer group.
 */
public class example4_6 extends ShellApp
{
    /**
     * The implementation of the Shell command, invoked when the command
     * is started by the user from the Shell.
     *
     * @param   args the command-line arguments passed to the command.
     * @return  a status code indicating the success or failure of 
     *          the command.
     */
    public int startApp(String[] args)
    {
        int result = appNoError;
        
        // Get the shell's environment.
        ShellEnv theEnvironment = getEnv();
        
        // Use the environment to obtain the current peer group.
        ShellObject theShellObject = theEnvironment.get("stdgroup");
        PeerGroup currentGroup = (PeerGroup) theShellObject.getObject();
         
        // Get the Discovery service for the current peer group.
        DiscoveryService discovery = currentGroup.getDiscoveryService();

        try
        {
            // Create an advertisement.
            PeerGroupAdvertisement advertisement =
                (PeerGroupAdvertisement) 
                    AdvertisementFactory.newAdvertisement(
                        PeerGroupAdvertisement.getAdvertisementType());
             
            // Populate the various fields. For most of this, we'll create
            // our own values, but we'll need the Module Spec ID of our 
            // current peer group.
            PeerGroupAdvertisement currentAdvertisement =
                currentGroup.getPeerGroupAdvertisement();
            
            // Set the values that must be unique for the new advertisement.
            advertisement.setName("NewGroup");
            advertisement.setDescription("PG for example4_6");
            advertisement.setPeerGroupID(IDFactory.newPeerGroupID());
            advertisement.setModuleSpecID(
                currentAdvertisement.getModuleSpecID());
            
            // Publish the advertisement locally.
            discovery.publish(advertisement, DiscoveryService.GROUP, 
                10000, 1000);
            
            // Publish the advertisement remotely.
            discovery.remotePublish(advertisement, 
                DiscoveryService.GROUP, 1000);
        }
        catch (IOException e)
        {
            println("Error publishing the advertisement to cache." + e);
            result = ShellApp.appMiscError;
        }
        
        return result;
    }
}