package net.jxta.impl.shell.bin.example5_2;

import net.jxta.impl.protocol.ResolverResponse;

import net.jxta.impl.shell.GetOpt;
import net.jxta.impl.shell.ShellApp;
import net.jxta.impl.shell.ShellEnv;
import net.jxta.impl.shell.ShellObject;

import net.jxta.impl.shell.bin.example5_1.ExampleResponseMsg;

import net.jxta.peergroup.PeerGroup;

import net.jxta.resolver.ResolverService;


/**
 * A simple application to demonstrate the use of the Resolver service to
 * send a Resolver Response Message without first receiving a Resolver   
 * Query Message.
 */
public class example5_2 extends ShellApp
{
    /**
     * The base value for the response.
     */
    private double base = 0.0;

    /**
     * The power value for the response.
     */
    private double power = 0.0;

    /**
     * The answer value for the response.
     */
    private double answer = 0;


    /**
     * Parses the command-line arguments and initializes the command
     *
     * @param       args the arguments to be parsed.
     * @exception   IllegalArgumentException if an invalid parameter 
     *             is passed.
     */
    private void parseArguments(String[] args) 
        throws IllegalArgumentException
    {
        int option;

        // Parse the arguments to the command.
        GetOpt parser = new GetOpt(args, "b:p:a:");

        while ((option = parser.getNextOption()) != -1)
        {
            switch (option)
            {
                case 'b' :
                {
                    try
                    {
                        // Obtain the "base" element for the response.
                        base = (new Double(
                            parser.getOptionArg())).doubleValue();
                    }
                    catch (Exception e)
                    {
                        // Default to 0.0
                        base = 0.0;
                    }

                    break;
                }
                
                case 'p' :
                {
                    try
                    {
                        // Obtain the "power" element for the response.
                        power = (new Double(
                            parser.getOptionArg())).doubleValue();
                    }
                    catch (Exception e)
                    {
                        // Default to 0.0
                        power = 0.0;
                    }

                    break;
                }
                
                case 'a' :
                {
                    try
                    {
                        // Obtain the "answer" element for the response.
                        answer =  (new Double(
                            parser.getOptionArg())).doubleValue();
                    }
                    catch (Exception e)
                    {
                        // Default to 0.0
                        answer = 0.0;
                    }

                    break;
                }
            }
        }
    }

    /**
     * The implementation of the Shell command, invoked when the command 
     * is started by the user from the Shell.
     *
     * @param   args the command-line arguments passed to the command.
     * @return  a status code indicating the success or failure of 
     *          the command.
     */
    public int startApp(String[] args)
    {
         int result = appNoError;

        // Get the shell's environment.
        ShellEnv theEnvironment = getEnv();

        // Use the environment to obtain the current peer group.
        ShellObject theShellObject = theEnvironment.get("stdgroup");
        PeerGroup currentGroup = (PeerGroup) theShellObject.getObject();

        // Get the Resolver service for the current peer group.
        ResolverService resolver = currentGroup.getResolverService();

        try
        {
            // Parse the command-line arguments.
            parseArguments(args);
        }
        catch (IllegalArgumentException e)
        {
            println("Incorrect parameters passed to the command.");
            return ShellApp.appParamError;
        }
            
        String localPeerId = currentGroup.getPeerID().toString();
        ExampleResponseMsg eresponse = 
            new ExampleResponseMsg(base, power, answer);
        // The following is the old API way of creating a ResolverResponse,
        // eliminated in the new (build 65e) stable release.
        //ResolverResponse pushRes = new ResolverResponse("ExampleHandler",
        //    "JXTACRED", 0, eresponse.toString());
        // Here is the new way:
        ResolverResponse pushRes = new ResolverResponse("ExampleHandler",
            null, 0, eresponse.toString());

        // Print out the information we're about to send.
        System.out.println(
            "Sending: base=" + base + ", power=" + power 
                + ", answer=" + answer);
        
        // Send the response using the resolver.
        resolver.sendResponse(null, pushRes);
        
        return result;
    }
}