package net.jxta.impl.shell.bin.example7_1;

import java.net.URL;

import net.jxta.id.IDFactory;

import net.jxta.peer.PeerID;
import net.jxta.peer.PeerInfoService;

import net.jxta.peergroup.PeerGroup;

import net.jxta.impl.shell.GetOpt;
import net.jxta.impl.shell.ShellApp;
import net.jxta.impl.shell.ShellEnv;
import net.jxta.impl.shell.ShellObject;


/**
 * A simple Shell command to demonstrate the use of the Peer Info
 * service and the PeerInfoListener interface to query remote peers for
 * status info.
 */
public class example7_1 extends ShellApp
{
    /**
     * The ID of the peer from whom peer info is being solicited.
     */
     private String peerid = null;

    
    /**
     * Parses the command-line arguments and initializes the command
     *
     * @param       args the arguments to be parsed.
     * @exception   IllegalArgumentException if an invalid parameter 
     *              is passed.
     */
    private void parseArguments(String[] args) 
        throws IllegalArgumentException
    {
        int option;

        // Parse the arguments to the command.
        GetOpt parser = new GetOpt(args, "p:");

        while ((option = parser.getNextOption()) != -1)
        {
            switch (option)
            {
                case 'p' :
                {
                    // Set the ID of the peer used to retrieve peer info.
                    peerid = parser.getOptionArg();

                    break;
                }
            }
        }
    }

    /**
     * Sends a query to a remote peer.
     *
     * @param   aPeerId the ID of the peer from whom to solicit status info.
     * @param   peerinfo the PeerInfoService to use to perform the query,
     */
    private void sendRemoteRequest(String aPeerId, PeerInfoService peerinfo)
    {
        try
        {
            // Transform the Peer ID string into a Peer ID object.
            PeerID peerIdObject = (PeerID) IDFactory.fromURL(
                new URL((aPeerId)));

            // Use the Peer Info service to query for the peer info.    
            peerinfo.getRemotePeerInfo(peerIdObject, new ExampleListener());
        }
        catch (Exception e)
        {
            System.out.println("Error parsing Peer ID string: " + e);
        }
    }

    /**
     * The implementation of the Shell command, invoked when the command 
     * is started by the user from the Shell.
     *
     * @param   args the command-line arguments passed to the command.
     * @return  a status code indicating the success or failure of 
     *          the command.
     */
    public int startApp(String[] args)
    {
        String peerid = null;
        int result = appNoError;

        // Get the shell's environment.
        ShellEnv theEnvironment = getEnv();

        // Use the environment to obtain the current peer group.
        ShellObject theShellObject = theEnvironment.get("stdgroup");
        PeerGroup currentGroup = (PeerGroup) theShellObject.getObject();

        // Get the Peer Info service for the current peer group.
        PeerInfoService peerinfo = currentGroup.getPeerInfoService();

        // Default to getting the local peer's status info.
        peerid = currentGroup.getPeerID().toString();

        try
        {
            // Parse the command-line arguments.
            parseArguments(args);
        }
        catch (IllegalArgumentException e)
        {
            println("Incorrect parameters passed to the command.");
            result = ShellApp.appParamError;
        }

        // Send a remote peer info request.
        System.out.println("Running example7_1...");
        sendRemoteRequest(peerid, peerinfo);

        return result;
    }
}